#ifndef foopulserefcnthfoo
#define foopulserefcnthfoo

/***
  This file is part of PulseAudio.

  Copyright 2006 Lennart Poettering

  PulseAudio is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as
  published by the Free Software Foundation; either version 2 of the
  License, or (at your option) any later version.

  PulseAudio is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with PulseAudio; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA.
***/

#include <pulsecore/atomic.h>

#define PA_REFCNT_DECLARE \
    pa_atomic_t _ref

#define PA_REFCNT_INIT(p) \
    pa_atomic_store(&(p)->_ref, 1)

#define PA_REFCNT_INIT_ZERO(p) \
    pa_atomic_store(&(p)->_ref, 0)

#define PA_REFCNT_INC(p) \
    pa_atomic_inc(&(p)->_ref)

#define PA_REFCNT_DEC(p) \
    (pa_atomic_dec(&(p)->_ref)-1)

#define PA_REFCNT_VALUE(p) \
    pa_atomic_load(&(p)->_ref)

#endif
